/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIFile.idl"

%{C++
      
#define NS_PROFILE_CID                                 \
  { /* {02b0625b-e7f3-11d2-9f5a-006008a6efe9} */       \
    0x02b0625b,                                        \
    0xe7f3,                                            \
    0x11d2,                                            \
    { 0x9f, 0x5a, 0x00, 0x60, 0x08, 0xa6, 0xef, 0xe9 } \
  }

#define NS_PROFILE_CONTRACTID	\
	"@mozilla.org/profile/manager;1"

#define NS_PROFILE_STARTUP_CATEGORY \
        "profile-startup-category"
%}

/**
 * nsIProfile
 * 
 * @status FROZEN
 * @version 1.0
 */

[scriptable, uuid(02b0625a-e7f3-11d2-9f5a-006008a6efe9)]
interface nsIProfile : nsISupports {
    
    readonly attribute long profileCount;
    void getProfileList(out unsigned long length, [retval, array, size_is(length)] out wstring profileNames); 
    boolean profileExists(in wstring profileName);

    attribute wstring currentProfile;

    const unsigned long SHUTDOWN_PERSIST      = 0x00000001;
    const unsigned long SHUTDOWN_CLEANSE      = 0x00000002;
    
    void shutDownCurrentProfile(in unsigned long shutDownType);

    void createNewProfile(in wstring profileName, 
                          in wstring nativeProfileDir, 
                          in wstring langcode,
                          in boolean useExistingDir);    

    void renameProfile(in wstring oldName, in wstring newName);
    void deleteProfile(in wstring name, in boolean canDeleteFiles);
    void cloneProfile(in wstring profileName);
};
